#!/bin/bash
# Automate Tomcat install script: v. 0.5
# Written by: Georgi Dimitrov Georgiev - gdgeorgiev@hpe.com
# Completion date: 03.02.2016
# !! Use at your own risk !!

##domain=$1
##java_version=$2
##tomcat_version=$3
##http=$4
##ajp=$5
##sdport=$6

# Define tomcat http port, ajp port, shutdown port and Proxy Url vars
http='10080';
ajp='11010';
sdport='21080'
proxy_url='http-proxy-ha.e-ssi.net:8080';
export https_proxy="$proxy_url"

# webdav host and dir - sl04097:/webdienste/dav/eoi/software # 

# Define download tomcat_url
tomcat_url='https://webdav.intranet.eon-it.com/eoi/software/tomcat';

# Define scripts download url
scripts_url='https://webdav.intranet.eon-it.com/eoi/software/scripts';

# Define avalable Tomcat available versions
tomcat[0]="tomcat8j18.tgz";
tomcat[1]="apache-tomcat-5.5.36.tar.gz";
tomcat[2]="apache-tomcat-6.0.44.tar.gz";
tomcat[3]="apache-tomcat-7.0.67.tar.gz";
tomcat[4]="apache-tomcat-8.0.30.tar.gz";
tomcat[5]="apache-tomcat-9.0.0.M1.tar.gz";

# Define java download url
java_url='https://webdav.intranet.eon-it.com/eoi/software/java';
java[0]="jdk-7u79-linux-i586.tar.gz";
java[1]="jdk-7u79-linux-x64.tar.gz";
java[2]="jdk-8u71-linux-i586.tar.gz";
java[3]="jdk-8u71-linux-x64.tar.gz";

# Enumerate tomcat, java array count
tomcat_cnt=${#tomcat[@]};
java_cnt=${#java[@]};


# Define tomcat available versions
tomcat_path='/webdienste/appserv-jsp/tomcat';
java_path='/webdienste/java/jdk';
temp_path='/webdienste/transfer/autoinstall';

###check_basic_args () {
###if [ "$#" -lt "5" ]; then
###echo "$0: not enough arguments.";
###echo "Usage: fqdn java_version tomcat_version http_port ajp_port shutdown_port. Http and ajp are required."
###exit 2
###fi
###}

# Get domain and ip_address args
get_args () {
read -p "Domain: " domain;
read -p "IP Address: " ip_address;
if [[ "$domain" == '' ]] || [[ "$ip_address" == '' ]]; then
echo 'Missing or improper domain or IP address argument';
get_args;
fi

}

# Choose Tomcat / Java version
choose_version () { 
# Choose tomcat version
##echo 'Choose Tomcat Version: ';
for i in $(seq 0 $(($tomcat_cnt - 1))); do
echo "$i. ${tomcat[$i]}";
done
read -p "Choose Tomcat version:" tomcat_version;
echo "$tomcat_version";

if [[ $tomcat_version -ne "1" ]] && [[ $tomcat_version -ne "2" ]] && [[ $tomcat_version -ne "3" ]] && [[ $tomcat_version -ne "3" ]] && [[ $tomcat_version -ne "4" ]] && [[ $tomcat_version -ne "5" ]]; then
echo "Version doesnt exist";
exit 0;
fi
tomcat_dir="$(echo ${tomcat[$tomcat_version]} | sed -e "s#.tar.gz##g")";

# Choose java version
##echo 'Choose Java Version';
for i in $(seq 0 $(($java_cnt - 1))); do
echo "$i. ${java[$i]}";
done
read -p "Choose Java version:" java_version;
echo "$java_version";

if [[ $java_version -ne "1" ]] && [[ $java_version -ne "2" ]] && [[ $java_version -ne "3" ]] && [[ $java_version -ne "3" ]] && [[ $java_version -ne "4" ]]; then
echo "Version doesnt exist";
exit 0;
fi

java_dir="$(echo ${java[$java_version]} | sed -e "s#.tar.gz##g")";


}

#Download tomcat

down_tomcat () {
# check whether $temp_path exists and download tomcat
if [ -d $temp_path ]; then
    cd $temp_path
    wget --no-check-certificate --timeout=5 $tomcat_url/${tomcat[$tomcat_version]}
    tar zxvf ${tomcat[$tomcat_version]}
else
mkdir $temp_path
    cd $temp_path
    wget --no-check-certificate --timeout=5 $tomcat_url/${tomcat[$tomcat_version]}
    tar zxvf ${tomcat[$tomcat_version]}
fi


#Tomcat create dirs
if [[ ! -d "$tomcat_path/${domain}" ]]; then
mkdir -p $tomcat_path/${domain}
   cd $temp_path/$tomcat_dir/
else
echo "Tomcat dir: temp_path/$tomcat_dir already existing, will not create.";
exit 1;
fi
##   wget --no-check-certificate --timeout=5 $tomcat_url/lib.tar.gz
##   echo "Extracting libs";
##   tar -zxvvf lib.tar.gz

# Disable unusued webapps if needed
read -p 'Disable common default webapps {balancer,jsp-examples,servlets-examples,tomcat-docs,webdav} [Y/N]:' disable
if [[ "$disable" == 'y' ]] || [[ "$disable" == 'Y' ]]; then
echo 'Removing Read / Write / Exec access from {balancer,jsp-examples,servlets-examples,tomcat-docs,webdav,examples,host-manager,manager}';
chmod 000 -R $temp_path/$tomcat_dir/webapps/{balancer,jsp-examples,servlets-examples,tomcat-docs,webdav,examples,host-manager,manager,docs} 2>&1 >/dev/null
fi
cp -rpf $temp_path/$tomcat_dir/ $tomcat_path/${domain}/
cd $tomcat_path/${domain}
if [[ ! -L $tomcat_path/$domain/current ]]; then
ln -sf $(ls -1 $tomcat_path/${domain}/) current
fi

    cd $tomcat_path/${domain}/current/bin/
echo "Downloading with wget setenv.sh";
  wget --no-check-certificate --timeout=5 $scripts_url/setenv.sh
  chmod +x $tomcat_path/${domain}/current/bin/setenv.sh
}

#Java create dirs

down_java () {
# get java dir var
java_dir="$(echo ${java[$version]} | sed -e "s#.tar.gz##g")";

# check whether temp_path exists and download java
if [ -d $temp_path ]; then
    cd $temp_path
    wget --no-check-certificate --timeout=5 $java_url/${java[$java_version]}
    tar zxvf ${java[$java_version]}
else
    mkdir -p $temp_path
    cd $temp_path
    wget --no-check-certificate --timeout=5 $java_url/${java[$java_version]}
    tar zxvf ${java[$java_version]}

fi


#Java create dir
if [[ ! -d $java_path/${domain} ]]; then
mkdir -p $java_path/${domain}/
else
echo "Will not create $java_path/$domain existing";
exit 1;
fi

# Copy extracted java to new domain dir
cp -rpf $temp_path/jdk*/ /webdienste/java/jdk/${domain}/

# Create current symlink
cd $java_path/${domain}/
if [[ ! -L $java_path/$domain/current ]]; then
ln -sf $(ls -1 $java_path/${domain}/) current
fi
##cd $java_path/${domain}/current/bin/

}


#Change tomcat config settings

fix_settings () {
#Change tomcat settings
echo '------------------------------------------------';
echo "Changing |setenv.sh| and |server.xml| Configurations ."
##sed -i "s/site_url.com/${domain}/" $tomcat_path/${domain}/current/bin/setenv.sh

# set ajp port number
sed -i "s/8009/${ajp}/" $tomcat_path/${domain}/current/conf/server.xml

# set ip address of new Tomcat in server.xml
sed -i "s/protocol=\"AJP\/1.3\"/protocol=\"AJP\/1.3\" address=\"${ip_address}\"/g" $tomcat_path/${domain}/current/conf/server.xml

# change shutdown port
sed -i "s/8005/${sdport}/" $tomcat_path/${domain}/current/conf/server.xml

# set proper domain url in setenv.sh
sed -i "s/site-url.com/${domain}/g" $tomcat_path/${domain}/current/bin/setenv.sh

# Add to .activ_instances.lst isf not existing
if [[ $(grep "${domain}" $tomcat_path/.activ_instances.lst) ]]; then 
echo "Will not add $domain to .active_instances.lst .. Existing."; 
else
echo "Adding $domain to $tomcat_path/.activ_instances.lst";
echo "$domain" >> $tomcat_path/.activ_instances.lst
fi

}

# Start tomcat 
startup () {

# Launch tomcat
cd $tomcat_path/${domain}/current/bin
echo '--------------------------------';
echo "Starting up Tomcat for ${domain}";
sh startup.sh
echo "Sleeping 10 seconds";
sleep 10;

# Show catalina.out messages
echo "Catalina.out messages";
if [ -f $tomcat_path/${domain}/current/logs/catalina.out ]; then
tail -n 50 $tomcat_path/${domain}/current/logs/catalina.out
else
echo "catalina.out not found .. exiting";
exit 1;
fi

}

# Cleanup obsolete created autinstall temp dir
cleanup () {
echo "Cleaning up everything in $temp_path";
rm -rf $temp_path/*
echo "---------------------------------------------------";
echo "If you need to enable some external libraries get them from: $tomcat_path/libs.tar.gz";
echo 'Run manually:';
echo
echo 'proxy_url='http-proxy-ha.e-ssi.net:8080'; export https_proxy="$proxy_url"'; 

echo "cd $temp_path/";
echo "E.g. wget --no-check-certificate --timeout=5 $tomcat_url/libs.tar.gz";
echo "N.B. ! Extracting all libs.tar.gz straight to $tomcat_path/$domain/current will crash Tomcat !"; 
echo '';

}

# Main 
main () {
###check_basic_args;
get_args;
choose_version;
down_tomcat;
down_java;
fix_settings;
startup;
cleanup;
}
main;
